'----------------------------------------------------------
' 
' GRIPLINK Integration for EPSON
' (c) Weiss Robotics GmbH & Co KG 2020
'
' Example program using the GRIPLINK interface
'
' Author: S. Wolfer <wolfer@weiss-robotics.com>
' Date: 2020-04-23
'
'----------------------------------------------------------

'----------------------------------------------------------
' Includes
'----------------------------------------------------------

#include "Griplink.inc"


'----------------------------------------------------------
' Defines 
'----------------------------------------------------------


'----------------------------------------------------------
' Global variables
'----------------------------------------------------------


'----------------------------------------------------------
' Module variables
'----------------------------------------------------------


'----------------------------------------------------------
' Functions
'----------------------------------------------------------

'
' Emergency stop handler
'
Function EmergencyStop
	UByte i
	Print "Emergency stop, disabling all connected grippers"
	For i = 0 To GRIPLINK_MAX_PORT
		Griplink_Disable(i)
	Next
Fend


'
' Example program running simple grip cycle
'
Function ExampleRun(ubGripper As UByte, ubGripIndex As UByte, boolIsCRG As Boolean)
	
	Boolean boolRes
	Boolean boolGrippers(GRIPLINK_NUM_PORTS)
	Integer intGripState
	
	'Set emergency stop handler
	Trap Emergency Xqt EmergencyStop
	
	Print "Connecting"
	Griplink_Connect("192.168.1.40", 201, 0)
	Print "Enable"
	Griplink_Enable(ubGripper)
	Print "Referencing"
	Griplink_Home(ubGripper)
	intGripState = Griplink_DevState(ubGripper)
	If intGripState = DS_DISABLED Then
		Do
			Print "Gripping"
			Griplink_Grip(ubGripper, ubGripIndex)
			intGripState = Griplink_DevState(ubGripper)
			If intGripState = DS_HOLDING Then
				Print "Holding part"
				Wait 2
			ElseIf intGripState = DS_NO_PART Then
				Print "No part detected"
			Else
				Print "Failed to grip with grip " + Str$(ubGripIndex) + " on gripper " + Str$(ubGripper)
				Exit Do
			EndIf
			Print "Releasing"
			Griplink_Release(ubGripper, ubGripIndex)
			intGripState = Griplink_DevState(ubGripper)
			If intGripState <> DS_RELEASED Then
				Print "Failed to release with grip " + Str$(ubGripIndex) + " on gripper " + Str$(ubGripper)
				Exit Do
			EndIf
		Loop
	Else
		Print "Failed to reference gripper " + Str$(ubGripper)
	EndIf
	
	Print "Test finished"
	
Fend


